@@ -15,6 +15,13 @@ class CSharpToCppTranslator:
         self.extra = extra
         self.Transform = self.compile = self.translate # callable objects
 
+        # create little magic ...
+        self.rules = CSharpToCppTranslator.FIRST_RULES[:]
+        for rule in self.extra:
+            self.rules.append(rule)
+        for i in CSharpToCppTranslator.LAST_RULES:
+            self.rules.append(i)
+
     def translate(self, src=None):
         """translate source code on C# to C++
         
@@ -29,13 +36,7 @@ class CSharpToCppTranslator:
         else:
             current = self.codeString[:]
 
-        rules = CSharpToCppTranslator.FIRST_RULES[:]
-        for rule in self.extra:
-            rules.append(rule)
-        for i in CSharpToCppTranslator.LAST_RULES:
-            rules.append(i)
-
-        for i in rules:
+        for i in self.rules:
             matchPattern = i[0]
             substitutionPattern = i[1]
             if len(i) < 3:
